pub struct ViewEpoch(/* private fields */);Expand description
Opaque monotonic epoch counter.
Incremented when the view system (via its configured EpochPolicy)
determines a discontinuity occurred that warrants segmenting temporal state.
Within a single uninterrupted feed session with CameraMode::Fixed,
the epoch never changes. Even for fixed feeds, epoch increments on feed restart.
Implementations